package sun.jdbc.odbc;

import java.math.BigDecimal;
import java.sql.DataTruncation;
import java.sql.SQLException;
import java.sql.SQLWarning;
import java.sql.Time;
import java.sql.Timestamp;
import java.util.Date;

public class JdbcOdbc extends JdbcOdbcObject {
   public static final int MajorVersion = 1;
   public static final int MinorVersion = 1001;

   public JdbcOdbc(String var1) throws SQLException {
      try {
         if (JdbcOdbcObject.isTracing()) {
            Date var2 = new Date();
            String var3 = "";
            short var4 = 1001;
            if (var4 < 1000) {
               var3 = var3 + "0";
            }

            if (var4 < 100) {
               var3 = var3 + "0";
            }

            if (var4 < 10) {
               var3 = var3 + "0";
            }

            var3 = var3 + "" + var4;
            JdbcOdbcObject.trace("JDBC to ODBC Bridge " + 1 + "." + var3);
            JdbcOdbcObject.trace("Current Date/Time: " + var2.toString());
            JdbcOdbcObject.trace("Loading " + var1 + "JdbcOdbc library");
         }

         System.loadLibrary(var1 + "JdbcOdbc");
      } catch (UnsatisfiedLinkError var5) {
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace("Unable to load " + var1 + "JdbcOdbc library");
         }

         throw new SQLException("Unable to load " + var1 + "JdbcOdbc library");
      }
   }

   public synchronized int SQLAllocConnect(int var1) throws SQLException {
      int var2 = 0;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Allocating Connection handle (SQLAllocConnect)");
      }

      byte[] var3 = new byte[1];
      var2 = this.allocConnect(var1, var3);
      if (var3[0] != 0) {
         this.throwGenericSQLException();
      } else if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("hDbc=" + var2);
      }

      return var2;
   }

   public synchronized int SQLAllocEnv() throws SQLException {
      int var1 = 0;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Allocating Environment handle (SQLAllocEnv)");
      }

      byte[] var2 = new byte[1];
      var1 = this.allocEnv(var2);
      if (var2[0] != 0) {
         this.throwGenericSQLException();
      } else if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("hEnv=" + var1);
      }

      return var1;
   }

   public synchronized int SQLAllocStmt(int var1) throws SQLException {
      int var2 = 0;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Allocating Statement Handle (SQLAllocStmt), hDbc=" + var1);
      }

      byte[] var3 = new byte[1];
      var2 = this.allocStmt(var1, var3);
      if (var3[0] != 0) {
         this.throwGenericSQLException();
      } else if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("hStmt=" + var2);
      }

      return var2;
   }

   public synchronized void SQLBindColDefault(int var1, int var2, byte[] var3, byte[] var4) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Binding default column (SQLBindCol), hStmt=" + var1 + ", ipar=" + var2 + ", length=" + var3.length);
      }

      byte[] var5 = new byte[1];
      this.bindColDefault(var1, var2, var3, var4, var5);
      if (var5[0] != 0) {
         this.standardError((short)var5[0], 0, 0, var1);
      }

   }

   public synchronized void SQLBindInParameterAtExec(int var1, int var2, int var3, int var4, byte[] var5, byte[] var6) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Binding DATA_AT_EXEC parameter (SQLBindParameter), hStmt=" + var1 + ", ipar=" + var2 + ", SQLtype=" + var3 + ", len=" + var4);
      }

      byte[] var7 = new byte[1];
      this.bindInParameterAtExec(var1, var2, var3, var4, var5, var6, var7);
      if (var7[0] != 0) {
         this.standardError((short)var7[0], 0, 0, var1);
      }

   }

   public synchronized void SQLBindInParameterBinary(int var1, int var2, int var3, byte[] var4, byte[] var5, byte[] var6) throws SQLException {
      int var8 = JdbcOdbcLimits.DEFAULT_IN_PRECISION;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Binding IN binary parameter (SQLBindParameter), hStmt=" + var1 + ", ipar=" + var2 + ", SQLtype=" + var3);
         JdbcOdbcObject.dumpByte(var4, var4.length);
      }

      byte[] var7 = new byte[1];
      this.bindInParameterBinary(var1, var2, OdbcDef.jdbcTypeToOdbc(var3), var4, var8, var5, var6, var7);
      if (var7[0] != 0) {
         this.standardError((short)var7[0], 0, 0, var1);
      }

   }

   public synchronized void SQLBindInParameterDate(int var1, int var2, java.sql.Date var3, byte[] var4) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Binding IN parameter date (SQLBindParameter), hStmt=" + var1 + ", ipar=" + var2 + ", rgbValue=" + var3.toString());
      }

      byte[] var5 = new byte[1];
      this.bindInParameterDate(var1, var2, ((Date)var3).getYear() + 1900, ((Date)var3).getMonth() + 1, ((Date)var3).getDate(), var4, var5);
      if (var5[0] != 0) {
         this.standardError((short)var5[0], 0, 0, var1);
      }

   }

   public synchronized void SQLBindInParameterDouble(int var1, int var2, int var3, int var4, double var5, byte[] var7) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Binding IN parameter double (SQLBindParameter), hStmt=" + var1 + ", ipar=" + var2 + ", SQLtype=" + var3 + ", scale=" + var4 + ", rgbValue=" + var5);
      }

      byte[] var8 = new byte[1];
      this.bindInParameterDouble(var1, var2, OdbcDef.jdbcTypeToOdbc(var3), var4, var5, var7, var8);
      if (var8[0] != 0) {
         this.standardError((short)var8[0], 0, 0, var1);
      }

   }

   public synchronized void SQLBindInParameterFloat(int var1, int var2, int var3, int var4, float var5, byte[] var6) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Binding IN parameter float (SQLBindParameter), hStmt=" + var1 + ", ipar=" + var2 + ", SQLtype=" + var3 + ", scale=" + var4 + ", rgbValue=" + var5);
      }

      byte[] var7 = new byte[1];
      this.bindInParameterFloat(var1, var2, OdbcDef.jdbcTypeToOdbc(var3), var4, var5, var6, var7);
      if (var7[0] != 0) {
         this.standardError((short)var7[0], 0, 0, var1);
      }

   }

   public synchronized void SQLBindInParameterInteger(int var1, int var2, int var3, int var4, byte[] var5) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Binding IN parameter integer (SQLBindParameter), hStmt=" + var1 + ", ipar=" + var2 + "SQLtype=" + var3 + ", rgbValue=" + var4);
      }

      byte[] var6 = new byte[1];
      this.bindInParameterInteger(var1, var2, OdbcDef.jdbcTypeToOdbc(var3), var4, var5, var6);
      if (var6[0] != 0) {
         this.standardError((short)var6[0], 0, 0, var1);
      }

   }

   public synchronized void SQLBindInParameterNull(int var1, int var2, int var3, byte[] var4) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Binding IN NULL parameter (SQLBindParameter), hStmt=" + var1 + ", ipar=" + var2 + ", SQLtype=" + var3);
      }

      byte[] var5 = new byte[1];
      this.bindInParameterNull(var1, var2, var3, var4, var5);
      if (var5[0] != 0) {
         this.standardError((short)var5[0], 0, 0, var1);
      }

   }

   public synchronized void SQLBindInParameterString(int var1, int var2, int var3, int var4, int var5, String var6, byte[] var7) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Binding IN string parameter (SQLBindParameter), hStmt=" + var1 + ", ipar=" + var2 + ", SQLtype=" + var3 + ", precision=" + var4 + ", scale=" + var5 + ", rgbValue=" + var6);
      }

      byte[] var8 = new byte[1];
      this.bindInParameterString(var1, var2, OdbcDef.jdbcTypeToOdbc(var3), var6, var4, var5, var7, var8);
      if (var8[0] != 0) {
         this.standardError((short)var8[0], 0, 0, var1);
      }

   }

   public synchronized void SQLBindInParameterTime(int var1, int var2, Time var3, byte[] var4) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Binding IN parameter time (SQLBindParameter), hStmt=" + var1 + ", ipar=" + var2 + ", rgbValue=" + var3.toString());
      }

      byte[] var5 = new byte[1];
      this.bindInParameterTime(var1, var2, ((Date)var3).getHours(), ((Date)var3).getMinutes(), ((Date)var3).getSeconds(), var4, var5);
      if (var5[0] != 0) {
         this.standardError((short)var5[0], 0, 0, var1);
      }

   }

   public synchronized void SQLBindInParameterTimestamp(int var1, int var2, Timestamp var3, byte[] var4) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Binding IN parameter timestamp (SQLBindParameter), hStmt=" + var1 + ", ipar=" + var2 + ", rgbValue=" + var3.toString());
      }

      byte[] var5 = new byte[1];
      this.bindInParameterTimestamp(var1, var2, ((Date)var3).getYear() + 1900, ((Date)var3).getMonth() + 1, ((Date)var3).getDate(), ((Date)var3).getHours(), ((Date)var3).getMinutes(), ((Date)var3).getSeconds(), var3.getNanos(), var4, var5);
      if (var5[0] != 0) {
         this.standardError((short)var5[0], 0, 0, var1);
      }

   }

   public synchronized void SQLBindOutParameterString(int var1, int var2, int var3, int var4, byte[] var5, byte[] var6) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Binding OUT string parameter (SQLBindParameter), hStmt=" + var1 + ", ipar=" + var2 + ", SQLtype=" + var3 + ", prec=" + (var5.length - 1) + ", scale=" + var4);
      }

      byte[] var7 = new byte[1];
      this.bindOutParameterString(var1, var2, var3, var4, var5, var6, var7);
      if (var7[0] != 0) {
         this.standardError((short)var7[0], 0, 0, var1);
      }

   }

   public synchronized String SQLBrowseConnect(int var1, String var2) throws SQLException, SQLWarning {
      String var5 = null;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Connecting (SQLBrowseConnect), hDbc=" + var1 + ", szConnStrIn=" + var2);
      }

      byte[] var3 = new byte[1];
      byte[] var4 = new byte[JdbcOdbcLimits.MAX_BROWSE_RESULT_LENGTH];
      this.browseConnect(var1, var2, var4, var3);
      if (var3[0] == 99) {
         var5 = new String(var4, 0);
         var5 = var5.trim();
         var3[0] = 0;
      }

      if (var3[0] != 0) {
         this.standardError((short)var3[0], 0, var1, 0);
      }

      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Attributes=" + var5);
      }

      return var5;
   }

   public synchronized void SQLCancel(int var1) throws SQLException, SQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Cancelling (SQLCancel), hStmt=" + var1);
      }

      byte[] var2 = new byte[1];
      this.cancel(var1, var2);
      if (var2[0] != 0) {
         this.standardError((short)var2[0], 0, 0, var1);
      }

   }

   public synchronized int SQLColAttributes(int var1, int var2, int var3) throws SQLException, JdbcOdbcSQLWarning {
      int var4 = 0;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Column attributes (SQLColAttributes), hStmt=" + var1 + ", icol=" + var2 + ", type=" + var3);
      }

      byte[] var5 = new byte[1];
      var4 = this.colAttributes(var1, var2, var3, var5);
      if (var5[0] != 0) {
         try {
            this.standardError((short)var5[0], 0, 0, var1);
         } catch (JdbcOdbcSQLWarning var7) {
            if (JdbcOdbcObject.isTracing()) {
               JdbcOdbcObject.trace("value (int)=" + var4);
            }

            var7.value = BigDecimal.valueOf((long)var4);
            throw var7;
         }
      } else if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("value (int)=" + var4);
      }

      return var4;
   }

   public synchronized String SQLColAttributesString(int var1, int var2, int var3) throws SQLException, JdbcOdbcSQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Column attributes (SQLColAttributes), hStmt=" + var1 + ", icol=" + var2 + ", type=" + var3);
      }

      byte[] var5 = new byte[1];
      byte[] var4 = new byte[JdbcOdbcLimits.DEFAULT_BUFFER_LENGTH];
      this.colAttributesString(var1, var2, var3, var4, var5);
      if (var5[0] != 0) {
         try {
            this.standardError((short)var5[0], 0, 0, var1);
         } catch (JdbcOdbcSQLWarning var8) {
            String var7 = new String(var4, 0);
            if (JdbcOdbcObject.isTracing()) {
               JdbcOdbcObject.trace("value (String)=" + var7.trim());
            }

            var8.value = var7.trim();
            throw var8;
         }
      }

      String var6 = new String(var4, 0);
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("value (String)=" + var6.trim());
      }

      return var6.trim();
   }

   public synchronized void SQLColumns(int var1, String var2, String var3, String var4, String var5) throws SQLException, SQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("(SQLColumns), hStmt=" + var1 + ", catalog=" + var2 + ", schema=" + var3 + ", table=" + var4 + ", column=" + var5);
      }

      byte[] var6 = new byte[1];
      this.columns(var1, var2, var2 == null, var3, var3 == null, var4, var4 == null, var5, var5 == null, var6);
      if (var6[0] != 0) {
         this.standardError((short)var6[0], 0, 0, var1);
      }

   }

   public synchronized void SQLColumnPrivileges(int var1, String var2, String var3, String var4, String var5) throws SQLException, SQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("(SQLColumnPrivileges), hStmt=" + var1 + ", catalog=" + var2 + ", schema=" + var3 + ", table=" + var4 + ", column=" + var5);
      }

      byte[] var6 = new byte[1];
      this.columnPrivileges(var1, var2, var2 == null, var3, var3 == null, var4, var4 == null, var5, var5 == null, var6);
      if (var6[0] != 0) {
         this.standardError((short)var6[0], 0, 0, var1);
      }

   }

   public synchronized boolean SQLDescribeParamNullable(int var1, int var2) throws SQLException, JdbcOdbcSQLWarning {
      boolean var5 = false;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Parameter nullable (SQLDescribeParam), hStmt=" + var1 + ", ipar=" + var2);
      }

      byte[] var3 = new byte[1];
      int var4 = this.describeParam(var1, var2, 4, var3);
      if (var3[0] != 0) {
         this.standardError((short)var3[0], 0, 0, var1);
      }

      if (var4 == 1) {
         var5 = true;
      }

      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("nullable=" + var5);
      }

      return var5;
   }

   public synchronized int SQLDescribeParamPrecision(int var1, int var2) throws SQLException, JdbcOdbcSQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Parameter precision (SQLDescribeParam), hStmt=" + var1 + ", ipar=" + var2);
      }

      byte[] var3 = new byte[1];
      int var4 = this.describeParam(var1, var2, 2, var3);
      if (var3[0] != 0) {
         this.standardError((short)var3[0], 0, 0, var1);
      }

      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("precision=" + var4);
      }

      return var4;
   }

   public synchronized int SQLDescribeParamScale(int var1, int var2) throws SQLException, JdbcOdbcSQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Parameter scale (SQLDescribeParam), hStmt=" + var1 + ", ipar=" + var2);
      }

      byte[] var3 = new byte[1];
      int var4 = this.describeParam(var1, var2, 3, var3);
      if (var3[0] != 0) {
         this.standardError((short)var3[0], 0, 0, var1);
      }

      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("scale=" + var4);
      }

      return var4;
   }

   public synchronized int SQLDescribeParamType(int var1, int var2) throws SQLException, JdbcOdbcSQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Parameter type (SQLDescribeParam), hStmt=" + var1 + ", ipar=" + var2);
      }

      byte[] var3 = new byte[1];
      int var4 = this.describeParam(var1, var2, 1, var3);
      if (var3[0] != 0) {
         this.standardError((short)var3[0], 0, 0, var1);
      }

      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("type=" + var4);
      }

      return var4;
   }

   public synchronized void SQLDisconnect(int var1) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Disconnecting (SQLDisconnect), hDbc=" + var1);
      }

      byte[] var2 = new byte[1];
      this.disconnect(var1, var2);
      if (var2[0] != 0) {
         this.standardError((short)var2[0], 0, var1, 0);
      }

   }

   public synchronized void SQLDriverConnect(int var1, String var2) throws SQLException, SQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Connecting (SQLDriverConnect), hDbc=" + var1 + ", szConnStrIn=" + var2);
      }

      byte[] var3 = new byte[1];
      this.driverConnect(var1, var2, var3);
      if (var3[0] != 0) {
         this.standardError((short)var3[0], 0, var1, 0);
      }

   }

   public synchronized void SQLExecDirect(int var1, String var2) throws SQLException, SQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Executing (SQLExecDirect), hStmt=" + var1 + ", szSqlStr=" + var2);
      }

      byte[] var3 = new byte[1];
      this.execDirect(var1, var2, var3);
      if (var3[0] != 0) {
         this.standardError((short)var3[0], 0, 0, var1);
      }

   }

   public synchronized boolean SQLExecute(int var1) throws SQLException, SQLWarning {
      boolean var3 = false;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Executing (SQLExecute), hStmt=" + var1);
      }

      byte[] var2 = new byte[1];
      this.execute(var1, var2);
      if (var2[0] == 99) {
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace("SQL_NEED_DATA returned");
         }

         var3 = true;
         var2[0] = 0;
      }

      if (var2[0] != 0) {
         this.standardError((short)var2[0], 0, 0, var1);
      }

      return var3;
   }

   public synchronized boolean SQLFetch(int var1) throws SQLException, SQLWarning {
      boolean var3 = true;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Fetching (SQLFetch), hStmt=" + var1);
      }

      byte[] var2 = new byte[1];
      this.fetch(var1, var2);
      if (var2[0] == 100) {
         var3 = false;
         var2[0] = 0;
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace("End of result set (SQL_NO_DATA)");
         }
      }

      if (var2[0] != 0) {
         this.standardError((short)var2[0], 0, 0, var1);
      }

      return var3;
   }

   public synchronized void SQLForeignKeys(int var1, String var2, String var3, String var4, String var5, String var6, String var7) throws SQLException, SQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("(SQLForeignKeys), hStmt=" + var1 + ", Pcatalog=" + var2 + ", Pschema=" + var3 + ", Ptable=" + var4 + ", Fcatalog=" + var5 + ", Fschema=" + var6 + ", Ftable=" + var7);
      }

      byte[] var8 = new byte[1];
      this.foreignKeys(var1, var2, var2 == null, var3, var3 == null, var4, var4 == null, var5, var5 == null, var6, var6 == null, var7, var7 == null, var8);
      if (var8[0] != 0) {
         this.standardError((short)var8[0], 0, 0, var1);
      }

   }

   public synchronized void SQLFreeConnect(int var1) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Closing connection (SQLFreeConnect), hDbc=" + var1);
      }

      byte[] var2 = new byte[1];
      this.freeConnect(var1, var2);
      if (var2[0] != 0) {
         this.standardError((short)var2[0], 0, var1, 0);
      }

   }

   public synchronized void SQLFreeEnv(int var1) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Closing environment (SQLFreeEnv), hEnv=" + var1);
      }

      byte[] var2 = new byte[1];
      this.freeEnv(var1, var2);
      if (var2[0] != 0) {
         this.throwGenericSQLException();
      }

   }

   public synchronized void SQLFreeStmt(int var1, int var2) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Free statement (SQLFreeStmt), hStmt=" + var1 + ", fOption=" + var2);
      }

      byte[] var3 = new byte[1];
      this.freeStmt(var1, var2, var3);
      if (var3[0] != 0) {
         this.throwGenericSQLException();
      }

   }

   public synchronized int SQLGetConnectOption(int var1, short var2) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Connection Option (SQLGetConnectOption), hDbc=" + var1 + ", fOption=" + var2);
      }

      byte[] var3 = new byte[1];
      int var4 = this.getConnectOption(var1, var2, var3);
      if (var3[0] != 0) {
         this.standardError((short)var3[0], 0, var1, 0);
      }

      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("option value (int)=" + var4);
      }

      return var4;
   }

   public synchronized String SQLGetConnectOptionString(int var1, short var2) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Connection Option (SQLGetConnectOption), hDbc=" + var1 + ", fOption=" + var2);
      }

      byte[] var3 = new byte[1];
      byte[] var4 = new byte[JdbcOdbcLimits.DEFAULT_BUFFER_LENGTH];
      this.getConnectOptionString(var1, var2, var4, var3);
      if (var3[0] != 0) {
         this.standardError((short)var3[0], 0, var1, 0);
      }

      String var5 = new String(var4, 0);
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("option value (int)=" + var5.trim());
      }

      return var5.trim();
   }

   public synchronized String SQLGetCursorName(int var1) throws SQLException, JdbcOdbcSQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Cursor name (SQLGetCursorName), hStmt=" + var1);
      }

      byte[] var3 = new byte[1];
      byte[] var2 = new byte[JdbcOdbcLimits.DEFAULT_BUFFER_LENGTH];
      this.getCursorName(var1, var2, var3);
      if (var3[0] != 0) {
         try {
            this.standardError((short)var3[0], 0, 0, var1);
         } catch (JdbcOdbcSQLWarning var6) {
            String var5 = new String(var2, 0);
            if (JdbcOdbcObject.isTracing()) {
               JdbcOdbcObject.trace("value=" + var5.trim());
            }

            var6.value = var5.trim();
            throw var6;
         }
      }

      String var4 = new String(var2, 0);
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("value=" + var4.trim());
      }

      return var4.trim();
   }

   public synchronized int SQLGetDataBinary(int var1, int var2, byte[] var3) throws SQLException, JdbcOdbcSQLWarning {
      return this.SQLGetDataBinary(var1, var2, -2, var3, var3.length);
   }

   public synchronized int SQLGetDataBinary(int var1, int var2, int var3, byte[] var4, int var5) throws SQLException, JdbcOdbcSQLWarning {
      int var7 = 0;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Get binary data (SQLGetData), hStmt=" + var1 + ", column=" + var2 + ", type=" + var3 + ", length=" + var5);
      }

      byte[] var6 = new byte[2];
      var7 = this.getDataBinary(var1, var2, var3, var4, var5, var6);
      if (var6[0] == 100) {
         var7 = -1;
         var6[0] = 0;
      }

      if (var6[0] != 0) {
         try {
            this.standardError((short)var6[0], 0, 0, var1);
         } catch (JdbcOdbcSQLWarning var9) {
            if (JdbcOdbcObject.isTracing()) {
               if (var7 == -1) {
                  JdbcOdbcObject.trace("NULL");
               } else if (JdbcOdbcObject.isTracing()) {
                  JdbcOdbcObject.trace("Bytes: " + var7);
               }
            }

            var9.value = new Integer(var7);
            throw var9;
         }
      }

      if (JdbcOdbcObject.isTracing()) {
         if (var7 == -1) {
            JdbcOdbcObject.trace("NULL");
         } else if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace("Bytes: " + var7);
         }
      }

      return var7;
   }

   public synchronized Double SQLGetDataDouble(int var1, int var2) throws SQLException, JdbcOdbcSQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Get double data (SQLGetData), hStmt=" + var1 + ", column=" + var2);
      }

      byte[] var3 = new byte[2];
      double var4 = this.getDataDouble(var1, var2, var3);
      if (var3[0] != 0) {
         try {
            this.standardError((short)var3[0], 0, 0, var1);
         } catch (JdbcOdbcSQLWarning var7) {
            if (var3[1] == 0) {
               if (JdbcOdbcObject.isTracing()) {
                  JdbcOdbcObject.trace("value=" + var4);
               }

               var7.value = new Double(var4);
            } else {
               if (JdbcOdbcObject.isTracing()) {
                  JdbcOdbcObject.trace("NULL");
               }

               var7.value = null;
            }

            throw var7;
         }
      }

      if (var3[1] == 0) {
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace("value=" + var4);
         }

         return new Double(var4);
      } else {
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace("NULL");
         }

         return null;
      }
   }

   public synchronized Float SQLGetDataFloat(int var1, int var2) throws SQLException, JdbcOdbcSQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Get float data (SQLGetData), hStmt=" + var1 + ", column=" + var2);
      }

      byte[] var3 = new byte[2];
      float var4 = this.getDataFloat(var1, var2, var3);
      if (var3[0] != 0) {
         try {
            this.standardError((short)var3[0], 0, 0, var1);
         } catch (JdbcOdbcSQLWarning var6) {
            if (var3[1] == 0) {
               if (JdbcOdbcObject.isTracing()) {
                  JdbcOdbcObject.trace("value=" + var4);
               }

               var6.value = new Float(var4);
            } else {
               if (JdbcOdbcObject.isTracing()) {
                  JdbcOdbcObject.trace("NULL");
               }

               var6.value = null;
            }

            throw var6;
         }
      }

      if (var3[1] == 0) {
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace("value=" + var4);
         }

         return new Float(var4);
      } else {
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace("NULL");
         }

         return null;
      }
   }

   public synchronized Integer SQLGetDataInteger(int var1, int var2) throws SQLException, JdbcOdbcSQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Get integer data (SQLGetData), hStmt=" + var1 + ", column=" + var2);
      }

      byte[] var3 = new byte[2];
      int var4 = this.getDataInteger(var1, var2, var3);
      if (var3[0] != 0) {
         try {
            this.standardError((short)var3[0], 0, 0, var1);
         } catch (JdbcOdbcSQLWarning var6) {
            if (var3[1] == 0) {
               if (JdbcOdbcObject.isTracing()) {
                  JdbcOdbcObject.trace("value=" + var4);
               }

               var6.value = new Integer(var4);
            } else {
               if (JdbcOdbcObject.isTracing()) {
                  JdbcOdbcObject.trace("NULL");
               }

               var6.value = null;
            }

            throw var6;
         }
      }

      if (var3[1] == 0) {
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace("value=" + var4);
         }

         return new Integer(var4);
      } else {
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace("NULL");
         }

         return null;
      }
   }

   public synchronized String SQLGetDataString(int var1, int var2, int var3, boolean var4) throws SQLException, JdbcOdbcSQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Get string data (SQLGetData), hStmt=" + var1 + ", column=" + var2 + ", maxLen=" + var3);
      }

      byte[] var5 = new byte[2];
      byte[] var6 = new byte[var3];
      int var7 = this.getDataString(var1, var2, var6, var5);
      if (var7 == 0) {
         var5[1] = 1;
      }

      if (var7 > var3) {
         var7 = var3;
      }

      if (var5[0] != 0) {
         try {
            this.standardError((short)var5[0], 0, 0, var1);
         } catch (JdbcOdbcSQLWarning var10) {
            if (var5[1] == 0) {
               String var9;
               if (var7 > 0) {
                  var9 = new String(var6, 0, 0, var7);
               } else {
                  var9 = new String(var6, 0);
               }

               if (JdbcOdbcObject.isTracing()) {
                  JdbcOdbcObject.trace(var9.trim());
               }

               if (var4) {
                  var10.value = var9.trim();
               } else {
                  var10.value = var9;
               }
            } else {
               if (JdbcOdbcObject.isTracing()) {
                  JdbcOdbcObject.trace("NULL");
               }

               var10.value = null;
            }

            throw var10;
         }
      }

      if (var5[1] == 0) {
         String var8;
         if (var7 > 0) {
            var8 = new String(var6, 0, 0, var7);
         } else {
            var8 = new String(var6, 0);
         }

         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace(var8.trim());
         }

         return var4 ? var8.trim() : var8;
      } else {
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace("NULL");
         }

         return null;
      }
   }

   public synchronized String SQLGetDataStringDate(int var1, int var2) throws SQLException, JdbcOdbcSQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Get date data (SQLGetData), hStmt=" + var1 + ", column=" + var2);
      }

      byte[] var3 = new byte[2];
      byte[] var4 = new byte[11];
      this.getDataStringDate(var1, var2, var4, var3);
      if (var3[0] != 0) {
         try {
            this.standardError((short)var3[0], 0, 0, var1);
         } catch (JdbcOdbcSQLWarning var7) {
            if (var3[1] == 0) {
               String var6 = new String(var4, 0);
               if (JdbcOdbcObject.isTracing()) {
                  JdbcOdbcObject.trace(var6.trim());
               }

               var7.value = var6.trim();
            } else {
               if (JdbcOdbcObject.isTracing()) {
                  JdbcOdbcObject.trace("NULL");
               }

               var7.value = null;
            }

            throw var7;
         }
      }

      if (var3[1] == 0) {
         String var5 = new String(var4, 0);
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace(var5.trim());
         }

         return var5.trim();
      } else {
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace("NULL");
         }

         return null;
      }
   }

   public synchronized String SQLGetDataStringTime(int var1, int var2) throws SQLException, JdbcOdbcSQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Get time data (SQLGetData), hStmt=" + var1 + ", column=" + var2);
      }

      byte[] var3 = new byte[2];
      byte[] var4 = new byte[9];
      this.getDataStringTime(var1, var2, var4, var3);
      if (var3[0] != 0) {
         try {
            this.standardError((short)var3[0], 0, 0, var1);
         } catch (JdbcOdbcSQLWarning var7) {
            if (var3[1] == 0) {
               String var6 = new String(var4, 0);
               if (JdbcOdbcObject.isTracing()) {
                  JdbcOdbcObject.trace(var6.trim());
               }

               var7.value = var6.trim();
            } else {
               if (JdbcOdbcObject.isTracing()) {
                  JdbcOdbcObject.trace("NULL");
               }

               var7.value = null;
            }

            throw var7;
         }
      }

      if (var3[1] == 0) {
         String var5 = new String(var4, 0);
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace(var5.trim());
         }

         return var5.trim();
      } else {
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace("NULL");
         }

         return null;
      }
   }

   public synchronized String SQLGetDataStringTimestamp(int var1, int var2) throws SQLException, JdbcOdbcSQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Get timestamp data (SQLGetData), hStmt=" + var1 + ", column=" + var2);
      }

      byte[] var3 = new byte[2];
      byte[] var4 = new byte[30];
      this.getDataStringTimestamp(var1, var2, var4, var3);
      if (var3[0] != 0) {
         try {
            this.standardError((short)var3[0], 0, 0, var1);
         } catch (JdbcOdbcSQLWarning var7) {
            if (var3[1] == 0) {
               String var6 = new String(var4, 0);
               if (JdbcOdbcObject.isTracing()) {
                  JdbcOdbcObject.trace(var6.trim());
               }

               var7.value = var6.trim();
            } else {
               if (JdbcOdbcObject.isTracing()) {
                  JdbcOdbcObject.trace("NULL");
               }

               var7.value = null;
            }

            throw var7;
         }
      }

      if (var3[1] == 0) {
         String var5 = new String(var4, 0);
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace(var5.trim());
         }

         return var5.trim();
      } else {
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace("NULL");
         }

         return null;
      }
   }

   public synchronized int SQLGetInfo(int var1, short var2) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Get connection info (SQLGetInfo), hDbc=" + var1 + ", fInfoType=" + var2);
      }

      byte[] var3 = new byte[1];
      int var4 = this.getInfo(var1, var2, var3);
      if (var3[0] != 0) {
         this.standardError((short)var3[0], 0, var1, 0);
      }

      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace(" int value=" + var4);
      }

      return var4;
   }

   public synchronized int SQLGetInfoShort(int var1, short var2) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Get connection info (SQLGetInfo), hDbc=" + var1 + ", fInfoType=" + var2);
      }

      byte[] var3 = new byte[1];
      int var4 = this.getInfoShort(var1, var2, var3);
      if (var3[0] != 0) {
         this.standardError((short)var3[0], 0, var1, 0);
      }

      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace(" short value=" + var4);
      }

      return var4;
   }

   public synchronized String SQLGetInfoString(int var1, short var2) throws SQLException {
      return this.SQLGetInfoString(var1, var2, JdbcOdbcLimits.DEFAULT_BUFFER_LENGTH);
   }

   public synchronized String SQLGetInfoString(int var1, short var2, int var3) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Get connection info string (SQLGetInfo), hDbc=" + var1 + ", fInfoType=" + var2 + ", len=" + var3);
      }

      byte[] var4 = new byte[1];
      byte[] var5 = new byte[var3];
      this.getInfoString(var1, var2, var5, var4);
      if (var4[0] != 0) {
         this.standardError((short)var4[0], 0, var1, 0);
      }

      String var6 = new String(var5, 0);
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace(var6.trim());
      }

      return var6.trim();
   }

   public synchronized int SQLGetStmtOption(int var1, short var2) throws SQLException, JdbcOdbcSQLWarning {
      int var3 = 0;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Get statement option (SQLGetStmtOption), hStmt=" + var1 + ", fOption=" + var2);
      }

      byte[] var4 = new byte[1];
      var3 = this.getStmtOption(var1, var2, var4);
      if (var4[0] != 0) {
         try {
            this.standardError((short)var4[0], 0, 0, var1);
         } catch (JdbcOdbcSQLWarning var6) {
            if (JdbcOdbcObject.isTracing()) {
               JdbcOdbcObject.trace("value=" + var3);
            }

            var6.value = BigDecimal.valueOf((long)var3);
            throw var6;
         }
      }

      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("value=" + var3);
      }

      return var3;
   }

   public synchronized void SQLGetTypeInfo(int var1, short var2) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Get type info (SQLGetTypeInfo), hStmt=" + var1 + ", fSqlType=" + var2);
      }

      byte[] var3 = new byte[1];
      this.getTypeInfo(var1, var2, var3);
      if (var3[0] != 0) {
         this.standardError((short)var3[0], 0, 0, var1);
      }

   }

   public synchronized boolean SQLMoreResults(int var1) throws SQLException, SQLWarning {
      boolean var3 = true;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Get more results (SQLMoreResults), hStmt=" + var1);
      }

      byte[] var2 = new byte[1];
      this.moreResults(var1, var2);
      if (var2[0] == 100) {
         var3 = false;
         var2[0] = 0;
      }

      if (var2[0] != 0) {
         this.standardError((short)var2[0], 0, 0, var1);
      }

      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("More results: " + var3);
      }

      return var3;
   }

   public synchronized String SQLNativeSql(int var1, String var2) throws SQLException {
      byte[] var3 = new byte[1];
      int var5 = JdbcOdbcLimits.DEFAULT_NATIVE_SQL_LENGTH;
      if (var2.length() * 4 > var5) {
         var5 = var2.length() * 4;
         if (var5 > 32768) {
            var5 = 32768;
         }
      }

      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Convert native SQL (SQLNativeSql), hDbc=" + var1 + ", nativeLen=" + var5 + ", SQL=" + var2);
      }

      byte[] var4 = new byte[var5];
      this.nativeSql(var1, var2, var4, var3);
      if (var3[0] != 0) {
         this.standardError((short)var3[0], 0, var1, 0);
      }

      String var6 = new String(var4, 0);
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Native SQL=" + var6.trim());
      }

      return var6.trim();
   }

   public synchronized int SQLNumParams(int var1) throws SQLException, JdbcOdbcSQLWarning {
      int var3 = 0;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Number of parameter markers (SQLNumParams), hStmt=" + var1);
      }

      byte[] var2 = new byte[1];
      var3 = this.numParams(var1, var2);
      if (var2[0] != 0) {
         this.standardError((short)var2[0], 0, 0, var1);
      }

      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("value=" + var3);
      }

      return var3;
   }

   public synchronized int SQLNumResultCols(int var1) throws SQLException, JdbcOdbcSQLWarning {
      int var3 = 0;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Number of result columns (SQLNumResultCols), hStmt=" + var1);
      }

      byte[] var2 = new byte[1];
      var3 = this.numResultCols(var1, var2);
      if (var2[0] != 0) {
         try {
            this.standardError((short)var2[0], 0, 0, var1);
         } catch (JdbcOdbcSQLWarning var5) {
            if (JdbcOdbcObject.isTracing()) {
               JdbcOdbcObject.trace("value=" + var3);
            }

            var5.value = BigDecimal.valueOf((long)var3);
            throw var5;
         }
      }

      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("value=" + var3);
      }

      return var3;
   }

   public synchronized int SQLParamData(int var1) throws SQLException, JdbcOdbcSQLWarning {
      int var3 = 0;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Get parameter number (SQLParamData), hStmt=" + var1);
      }

      byte[] var2 = new byte[1];
      var3 = this.paramData(var1, var2);
      if (var2[0] == 99) {
         var2[0] = 0;
      } else {
         var3 = -1;
      }

      if (var2[0] != 0) {
         this.standardError((short)var2[0], 0, 0, var1);
      }

      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Parameter needing data=" + var3);
      }

      return var3;
   }

   public synchronized void SQLPrepare(int var1, String var2) throws SQLException, SQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Preparing (SQLPrepare), hStmt=" + var1 + ", szSqlStr=" + var2);
      }

      byte[] var3 = new byte[1];
      this.prepare(var1, var2, var3);
      if (var3[0] != 0) {
         this.standardError((short)var3[0], 0, 0, var1);
      }

   }

   public synchronized void SQLPutData(int var1, byte[] var2, int var3) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Putting data (SQLPutData), hStmt=" + var1 + ", len=" + var3);
      }

      byte[] var4 = new byte[1];
      this.putData(var1, var2, var3, var4);
      if (var4[0] != 0) {
         this.standardError((short)var4[0], 0, 0, var1);
      }

   }

   public synchronized void SQLPrimaryKeys(int var1, String var2, String var3, String var4) throws SQLException, SQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Primary keys (SQLPrimaryKeys), hStmt=" + var1 + ", catalog=" + var2 + ", schema=" + var3 + ", table=" + var4);
      }

      byte[] var5 = new byte[1];
      this.primaryKeys(var1, var2, var2 == null, var3, var3 == null, var4, var4 == null, var5);
      if (var5[0] != 0) {
         this.standardError((short)var5[0], 0, 0, var1);
      }

   }

   public synchronized void SQLProcedures(int var1, String var2, String var3, String var4) throws SQLException, SQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Procedures (SQLProcedures), hStmt=" + var1 + ", catalog=" + var2 + ", schema=" + var3 + ", procedure=" + var4);
      }

      byte[] var5 = new byte[1];
      this.procedures(var1, var2, var2 == null, var3, var3 == null, var4, var4 == null, var5);
      if (var5[0] != 0) {
         this.standardError((short)var5[0], 0, 0, var1);
      }

   }

   public synchronized void SQLProcedureColumns(int var1, String var2, String var3, String var4, String var5) throws SQLException, SQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Procedure columns (SQLProcedureColumns), hStmt=" + var1 + ", catalog=" + var2 + ", schema=" + var3 + ", procedure=" + var4 + ", column=" + var5);
      }

      byte[] var6 = new byte[1];
      this.procedureColumns(var1, var2, var2 == null, var3, var3 == null, var4, var4 == null, var5, var5 == null, var6);
      if (var6[0] != 0) {
         this.standardError((short)var6[0], 0, 0, var1);
      }

   }

   public synchronized int SQLRowCount(int var1) throws SQLException, JdbcOdbcSQLWarning {
      int var3 = 0;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Number of affected rows (SQLRowCount), hStmt=" + var1);
      }

      byte[] var2 = new byte[1];
      var3 = this.rowCount(var1, var2);
      if (var2[0] != 0) {
         try {
            this.standardError((short)var2[0], 0, 0, var1);
         } catch (JdbcOdbcSQLWarning var5) {
            if (JdbcOdbcObject.isTracing()) {
               JdbcOdbcObject.trace("value=" + var3);
            }

            var5.value = BigDecimal.valueOf((long)var3);
            throw var5;
         }
      }

      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("value=" + var3);
      }

      return var3;
   }

   public synchronized void SQLSetConnectOption(int var1, short var2, int var3) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Setting connection option (SQLSetConnectOption), hDbc=" + var1 + ", fOption=" + var2 + ", vParam=" + var3);
      }

      byte[] var4 = new byte[1];
      this.setConnectOption(var1, var2, var3, var4);
      if (var4[0] != 0) {
         this.standardError((short)var4[0], 0, var1, 0);
      }

   }

   public synchronized void SQLSetConnectOption(int var1, short var2, String var3) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Setting connection option string (SQLSetConnectOption), hDbc=" + var1 + ", fOption=" + var2 + ", vParam=" + var3);
      }

      byte[] var4 = new byte[1];
      this.setConnectOptionString(var1, var2, var3, var4);
      if (var4[0] != 0) {
         this.standardError((short)var4[0], 0, var1, 0);
      }

   }

   public synchronized void SQLSetCursorName(int var1, String var2) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Setting cursor name (SQLSetCursorName), hStmt=" + var1 + ", szCursor=" + var2);
      }

      byte[] var3 = new byte[1];
      this.setCursorName(var1, var2, var3);
      if (var3[0] != 0) {
         this.standardError((short)var3[0], 0, 0, var1);
      }

   }

   public synchronized void SQLSetStmtOption(int var1, short var2, int var3) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Setting statement option (SQLSetStmtOption), hStmt=" + var1 + ", fOption=" + var2 + ", vParam=" + var3);
      }

      byte[] var4 = new byte[1];
      this.setStmtOption(var1, var2, var3, var4);
      if (var4[0] != 0) {
         this.standardError((short)var4[0], 0, 0, var1);
      }

   }

   public synchronized void SQLSpecialColumns(int var1, short var2, String var3, String var4, String var5, int var6, boolean var7) throws SQLException, SQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Special columns (SQLSpecialColumns), hStmt=" + var1 + ", fColType=" + var2 + ",catalog=" + var3 + ", schema=" + var4 + ", table=" + var5 + ", fScope=" + var6 + ", fNullable=" + var7);
      }

      byte[] var8 = new byte[1];
      this.specialColumns(var1, var2, var3, var3 == null, var4, var4 == null, var5, var5 == null, var6, var7, var8);
      if (var8[0] != 0) {
         this.standardError((short)var8[0], 0, 0, var1);
      }

   }

   public synchronized void SQLStatistics(int var1, String var2, String var3, String var4, boolean var5, boolean var6) throws SQLException, SQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Statistics (SQLStatistics), hStmt=" + var1 + ",catalog=" + var2 + ", schema=" + var3 + ", table=" + var4 + ", unique=" + var5 + ", approximate=" + var6);
      }

      byte[] var7 = new byte[1];
      this.statistics(var1, var2, var2 == null, var3, var3 == null, var4, var4 == null, var5, var6, var7);
      if (var7[0] != 0) {
         this.standardError((short)var7[0], 0, 0, var1);
      }

   }

   public synchronized void SQLTables(int var1, String var2, String var3, String var4, String var5) throws SQLException, SQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Tables (SQLTables), hStmt=" + var1 + ",catalog=" + var2 + ", schema=" + var3 + ", table=" + var4 + ", types=" + var5);
      }

      byte[] var6 = new byte[1];
      this.tables(var1, var2, var2 == null, var3, var3 == null, var4, var4 == null, var5, var5 == null, var6);
      if (var6[0] != 0) {
         this.standardError((short)var6[0], 0, 0, var1);
      }

   }

   public synchronized void SQLTablePrivileges(int var1, String var2, String var3, String var4) throws SQLException, SQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Tables (SQLTables), hStmt=" + var1 + ",catalog=" + var2 + ", schema=" + var3 + ", table=" + var4);
      }

      byte[] var5 = new byte[1];
      this.tablePrivileges(var1, var2, var2 == null, var3, var3 == null, var4, var4 == null, var5);
      if (var5[0] != 0) {
         this.standardError((short)var5[0], 0, 0, var1);
      }

   }

   public synchronized void SQLTransact(int var1, int var2, short var3) throws SQLException {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("Transaction (SQLTransact), hEnv=" + var1 + ", hDbc=" + var2 + ", fType=" + var3);
      }

      byte[] var4 = new byte[1];
      this.transact(var1, var2, var3, var4);
      if (var4[0] != 0) {
         this.throwGenericSQLException();
      }

   }

   public native int bufferToInt(byte[] var1);

   public static SQLWarning convertWarning(JdbcOdbcSQLWarning var0) {
      Object var1 = var0;
      if (((SQLException)var0).getSQLState().equals("01004")) {
         DataTruncation var2 = new DataTruncation(-1, false, true, 0, 0);
         var1 = var2;
      }

      return (SQLWarning)var1;
   }

   protected native int allocConnect(int var1, byte[] var2);

   protected native int allocEnv(byte[] var1);

   protected native int allocStmt(int var1, byte[] var2);

   protected native void cancel(int var1, byte[] var2);

   protected native void bindColDefault(int var1, int var2, byte[] var3, byte[] var4, byte[] var5);

   protected native void bindInParameterAtExec(int var1, int var2, int var3, int var4, byte[] var5, byte[] var6, byte[] var7);

   protected native void bindInParameterBinary(int var1, int var2, int var3, byte[] var4, int var5, byte[] var6, byte[] var7, byte[] var8);

   protected native void bindInParameterDate(int var1, int var2, int var3, int var4, int var5, byte[] var6, byte[] var7);

   protected native void bindInParameterDouble(int var1, int var2, int var3, int var4, double var5, byte[] var7, byte[] var8);

   protected native void bindInParameterFloat(int var1, int var2, int var3, int var4, float var5, byte[] var6, byte[] var7);

   protected native void bindInParameterInteger(int var1, int var2, int var3, int var4, byte[] var5, byte[] var6);

   protected native void bindInParameterNull(int var1, int var2, int var3, byte[] var4, byte[] var5);

   protected native void bindInParameterString(int var1, int var2, int var3, String var4, int var5, int var6, byte[] var7, byte[] var8);

   protected native void bindInParameterTime(int var1, int var2, int var3, int var4, int var5, byte[] var6, byte[] var7);

   protected native void bindInParameterTimestamp(int var1, int var2, int var3, int var4, int var5, int var6, int var7, int var8, int var9, byte[] var10, byte[] var11);

   protected native void bindOutParameterString(int var1, int var2, int var3, int var4, byte[] var5, byte[] var6, byte[] var7);

   protected native void browseConnect(int var1, String var2, byte[] var3, byte[] var4);

   protected native int colAttributes(int var1, int var2, int var3, byte[] var4);

   protected native void colAttributesString(int var1, int var2, int var3, byte[] var4, byte[] var5);

   protected native void columns(int var1, String var2, boolean var3, String var4, boolean var5, String var6, boolean var7, String var8, boolean var9, byte[] var10);

   protected native void columnPrivileges(int var1, String var2, boolean var3, String var4, boolean var5, String var6, boolean var7, String var8, boolean var9, byte[] var10);

   protected native int describeParam(int var1, int var2, int var3, byte[] var4);

   protected native void disconnect(int var1, byte[] var2);

   protected native void driverConnect(int var1, String var2, byte[] var3);

   protected native int error(int var1, int var2, int var3, byte[] var4, byte[] var5, byte[] var6);

   protected native void execDirect(int var1, String var2, byte[] var3);

   protected native void execute(int var1, byte[] var2);

   protected native void fetch(int var1, byte[] var2);

   protected native void foreignKeys(int var1, String var2, boolean var3, String var4, boolean var5, String var6, boolean var7, String var8, boolean var9, String var10, boolean var11, String var12, boolean var13, byte[] var14);

   protected native void freeConnect(int var1, byte[] var2);

   protected native void freeEnv(int var1, byte[] var2);

   protected native void freeStmt(int var1, int var2, byte[] var3);

   protected native int getConnectOption(int var1, short var2, byte[] var3);

   protected native void getConnectOptionString(int var1, short var2, byte[] var3, byte[] var4);

   protected native void getCursorName(int var1, byte[] var2, byte[] var3);

   protected native int getStmtOption(int var1, short var2, byte[] var3);

   protected native int getDataBinary(int var1, int var2, int var3, byte[] var4, int var5, byte[] var6);

   protected native double getDataDouble(int var1, int var2, byte[] var3);

   protected native float getDataFloat(int var1, int var2, byte[] var3);

   protected native int getDataInteger(int var1, int var2, byte[] var3);

   protected native int getDataString(int var1, int var2, byte[] var3, byte[] var4);

   protected native void getDataStringDate(int var1, int var2, byte[] var3, byte[] var4);

   protected native void getDataStringTime(int var1, int var2, byte[] var3, byte[] var4);

   protected native void getDataStringTimestamp(int var1, int var2, byte[] var3, byte[] var4);

   protected native int getInfo(int var1, short var2, byte[] var3);

   protected native int getInfoShort(int var1, short var2, byte[] var3);

   protected native void getInfoString(int var1, short var2, byte[] var3, byte[] var4);

   protected native void getTypeInfo(int var1, short var2, byte[] var3);

   protected native void moreResults(int var1, byte[] var2);

   protected native void nativeSql(int var1, String var2, byte[] var3, byte[] var4);

   protected native int numParams(int var1, byte[] var2);

   protected native int numResultCols(int var1, byte[] var2);

   protected native int paramData(int var1, byte[] var2);

   protected native void prepare(int var1, String var2, byte[] var3);

   protected native void primaryKeys(int var1, String var2, boolean var3, String var4, boolean var5, String var6, boolean var7, byte[] var8);

   protected native void procedures(int var1, String var2, boolean var3, String var4, boolean var5, String var6, boolean var7, byte[] var8);

   protected native void procedureColumns(int var1, String var2, boolean var3, String var4, boolean var5, String var6, boolean var7, String var8, boolean var9, byte[] var10);

   protected native void putData(int var1, byte[] var2, int var3, byte[] var4);

   protected native int rowCount(int var1, byte[] var2);

   protected native void setConnectOption(int var1, short var2, int var3, byte[] var4);

   protected native void setConnectOptionString(int var1, short var2, String var3, byte[] var4);

   protected native void setCursorName(int var1, String var2, byte[] var3);

   protected native void setStmtOption(int var1, short var2, int var3, byte[] var4);

   protected native void specialColumns(int var1, short var2, String var3, boolean var4, String var5, boolean var6, String var7, boolean var8, int var9, boolean var10, byte[] var11);

   protected native void statistics(int var1, String var2, boolean var3, String var4, boolean var5, String var6, boolean var7, boolean var8, boolean var9, byte[] var10);

   protected native void tables(int var1, String var2, boolean var3, String var4, boolean var5, String var6, boolean var7, String var8, boolean var9, byte[] var10);

   protected native void tablePrivileges(int var1, String var2, boolean var3, String var4, boolean var5, String var6, boolean var7, byte[] var8);

   protected native void transact(int var1, int var2, short var3, byte[] var4);

   SQLException createSQLException(int var1, int var2, int var3) {
      boolean var8 = false;
      SQLException var9 = null;
      SQLException var10 = null;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("ERROR - Generating SQLException...");
      }

      while(!var8) {
         byte[] var6 = new byte[1];
         byte[] var4 = new byte[6];
         byte[] var5 = new byte[JdbcOdbcLimits.DEFAULT_BUFFER_LENGTH];
         int var7 = this.error(var1, var2, var3, var4, var5, var6);
         if (var6[0] != 0) {
            var8 = true;
         } else {
            Object var11 = null;
            String var12 = new String(var5, 0);
            String var13 = new String(var4, 0);
            SQLException var14 = new SQLException(var12.trim(), var13.trim(), var7);
            if (var9 == null) {
               var9 = var14;
            } else {
               var10.setNextException(var14);
            }

            var10 = var14;
         }
      }

      if (var9 == null) {
         String var15 = "General error";
         String var16 = "S1000";
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace("ERROR - " + var16 + " " + var15);
         }

         var9 = new SQLException(var15, var16);
      }

      return var9;
   }

   SQLWarning createSQLWarning(int var1, int var2, int var3) {
      boolean var8 = false;
      JdbcOdbcSQLWarning var9 = null;
      JdbcOdbcSQLWarning var10 = null;
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("WARNING - Generating SQLWarning...");
      }

      while(!var8) {
         byte[] var6 = new byte[1];
         byte[] var4 = new byte[6];
         byte[] var5 = new byte[JdbcOdbcLimits.DEFAULT_BUFFER_LENGTH];
         int var7 = this.error(var1, var2, var3, var4, var5, var6);
         if (var6[0] != 0) {
            var8 = true;
         } else {
            Object var11 = null;
            String var12 = new String(var5, 0);
            String var13 = new String(var4, 0);
            JdbcOdbcSQLWarning var14 = new JdbcOdbcSQLWarning(var12.trim(), var13.trim(), var7);
            if (var9 == null) {
               var9 = var14;
            } else {
               ((SQLWarning)var10).setNextWarning(var14);
            }

            var10 = var14;
         }
      }

      if (var9 == null) {
         String var15 = "General warning";
         String var16 = "S1000";
         if (JdbcOdbcObject.isTracing()) {
            JdbcOdbcObject.trace("WARNING - " + var16 + " " + var15);
         }

         var9 = new JdbcOdbcSQLWarning(var15, var16);
      }

      return var9;
   }

   void throwGenericSQLException() throws SQLException {
      String var1 = "General error";
      String var2 = "S1000";
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("ERROR - " + var2 + " " + var1);
      }

      throw new SQLException(var1, var2);
   }

   void standardError(short var1, int var2, int var3, int var4) throws SQLException, SQLWarning {
      if (JdbcOdbcObject.isTracing()) {
         JdbcOdbcObject.trace("RETCODE = " + var1);
      }

      switch (var1) {
         case -2:
            String var6 = "Invalid handle";
            if (JdbcOdbcObject.isTracing()) {
               JdbcOdbcObject.trace("ERROR - " + var6);
            }

            throw new SQLException(var6);
         case -1:
            throw this.createSQLException(var2, var3, var4);
         case 1:
            throw this.createSQLWarning(var2, var3, var4);
         case 100:
            String var5 = "No data found";
            if (JdbcOdbcObject.isTracing()) {
               JdbcOdbcObject.trace("ERROR - " + var5);
            }

            throw new SQLException(var5);
         default:
            this.throwGenericSQLException();
      }
   }
}
